==> rendition-14.10.0.tgz: package/dist_esm5/components/Steps/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import { faCheck } from '@fortawesome/free-solid-svg-icons/faCheck';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import findIndex from 'lodash/findIndex';
import * as React from 'react';
import styled, { css } from 'styled-components';
import asRendition from '../../asRendition';
import Arrow from '../../internal/Arrow';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Link from '../Link';
import Txt from '../Txt';
var getIconBg = function (theme, ordered, status, active) {
    var bgColor = ordered ? '#fff' : theme.colors.tertiary.semilight;
    var completed = status === 'completed';
    if (active) {
        bgColor = theme.colors.primary.main;
    }
    else if (completed) {
        bgColor = theme.colors.success.main;
    }
    var size = px(theme.fontSizes[4]);
    return css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t\tborder-radius: 50%;\n\t\tborder: ", ";\n\t\tcolor: ", ";\n\t\tbackground-color: ", ";\n\t\theight: ", ";\n\t\twidth: ", ";\n\t"], ["\n\t\tborder-radius: 50%;\n\t\tborder: ",
        ";\n\t\tcolor: ",
        ";\n\t\tbackground-color: ", ";\n\t\theight: ", ";\n\t\twidth: ", ";\n\t"])), completed || active || !ordered
        ? 'none'
        : "solid 1px " + theme.colors.tertiary.semilight, !ordered || completed || active
        ? '#fff'
        : theme.colors.tertiary.semilight, bgColor, size, size);
};
var StepIconBg = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t", ";\n"], ["\n\t", ";\n"])), function (props) { return getIconBg(props.theme, props.ordered, props.status, props.active); });
var StepIcon = function (_a) {
    var ordered = _a.ordered, status = _a.status, active = _a.active, index = _a.index;
    if (status === 'none') {
        return null;
    }
    return (React.createElement(StepIconBg, { mr: 2, alignItems: "center", justifyContent: "center", ordered: ordered, status: status, active: active }, !ordered || (status === 'completed' && !active) ? (React.createElement(FontAwesomeIcon, { icon: faCheck })) : (React.createElement(Txt, null, index + 1))));
};
export var Step = function (_a) {
    var ordered = _a.ordered, active = _a.active, index = _a.index, status = _a.status, children = _a.children, onClick = _a.onClick;
    if (typeof children !== 'string') {
        throw new Error('The child of a Step has to be a string.');
    }
    return (React.createElement(Flex, { flexDirection: "row", justifyContent: "center", alignItems: "center" },
        React.createElement(StepIcon, { ordered: Boolean(ordered), status: status, active: Boolean(active), index: index }),
        onClick ? (React.createElement(Link, { onClick: onClick }, children)) : (React.createElement(Txt, { bold: active, color: active ? undefined : 'tertiary.light' }, children))));
};
var FramelessSteps = function (_a) {
    var ordered = _a.ordered, activeStepIndex = _a.activeStepIndex, children = _a.children, otherProps = __rest(_a, ["ordered", "activeStepIndex", "children"]);
    return (React.createElement(Flex, __assign({ mx: "auto", flexDirection: "row", alignItems: "center", flexWrap: "wrap" }, otherProps), React.Children.map(children, function (step, index) {
        if (step.type !== Step) {
            throw new Error('You can only use Step components as children of Steps.');
        }
        var firstPendingStepIndex = findIndex(children, {
            props: { status: 'pending' },
        });
        var enableNextStep = !ordered ||
            firstPendingStepIndex === -1 ||
            firstPendingStepIndex > index;
        var allPrevStepsComplete = firstPendingStepIndex === -1 || firstPendingStepIndex >= index;
        var onClick = !ordered ||
            index < activeStepIndex ||
            (index !== activeStepIndex && allPrevStepsComplete)
            ? step.props.onClick
            : undefined;
        return (React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
            React.cloneElement(step, {
                ordered: ordered,
                index: index,
                onClick: onClick,
                active: activeStepIndex === index,
            }),
            index < children.length - 1 && (React.createElement(Flex, { justifyContent: "center", alignItems: "center", mx: 3 },
                React.createElement(Arrow, { disabled: !enableNextStep })))));
    })));
};
var Steps = React.forwardRef(function (_a, ref) {
    var theme = _a.theme, className = _a.className, children = _a.children, ordered = _a.ordered, bordered = _a.bordered, activeStepIndex = _a.activeStepIndex, titleText = _a.titleText, titleIcon = _a.titleIcon, onClose = _a.onClose;
    if (ordered) {
        if (typeof activeStepIndex !== 'number') {
            throw new Error('You must specify the activeStepIndex for ordered Steps');
        }
        else {
            var stepCount = React.Children.count(children);
            if (activeStepIndex < 0 || activeStepIndex >= stepCount) {
                throw new Error('activeStepIndex is out of range');
            }
        }
    }
    return (React.createElement(DismissableContainer, { p: 3, className: className, flexDirection: "row", justifyContent: "space-between", flexWrap: "wrap", alignItems: "center", onDismiss: onClose, baselineHeight: 34, bordered: bordered, ref: ref },
        (titleText || titleIcon) && (React.createElement(Flex, { minHeight: theme.fontSizes[5], justifyContent: "center", alignItems: "center", ml: 2, mr: 4 },
            titleIcon && (React.createElement(Txt, { fontSize: 2, mr: 2, color: "tertiary.semilight" }, titleIcon)),
            titleText && (React.createElement(Heading.h6, { color: "tertiary.main" }, titleText)))),
        React.createElement(FramelessSteps, { ordered: Boolean(ordered), activeStepIndex: activeStepIndex }, children)));
});
Steps.defaultProps = {
    bordered: true,
    ordered: false,
};
export default asRendition(Steps);
var templateObject_1, templateObject_2;

==> rendition-14.12.0.tgz: package/dist_esm5/components/Steps/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import { faCheck } from '@fortawesome/free-solid-svg-icons/faCheck';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import findIndex from 'lodash/findIndex';
import * as React from 'react';
import styled, { css } from 'styled-components';
import asRendition from '../../asRendition';
import Arrow from '../../internal/Arrow';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { px } from '../../utils';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Link from '../Link';
import Txt from '../Txt';
var getIconBg = function (theme, ordered, status, active) {
    var bgColor = ordered ? '#fff' : theme.colors.tertiary.semilight;
    var completed = status === 'completed';
    if (active) {
        bgColor = theme.colors.primary.main;
    }
    else if (completed) {
        bgColor = theme.colors.success.main;
    }
    var size = px(theme.fontSizes[4]);
    return css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t\tborder-radius: 50%;\n\t\tborder: ", ";\n\t\tcolor: ", ";\n\t\tbackground-color: ", ";\n\t\theight: ", ";\n\t\twidth: ", ";\n\t"], ["\n\t\tborder-radius: 50%;\n\t\tborder: ",
        ";\n\t\tcolor: ",
        ";\n\t\tbackground-color: ", ";\n\t\theight: ", ";\n\t\twidth: ", ";\n\t"])), completed || active || !ordered
        ? 'none'
        : "solid 1px " + theme.colors.tertiary.semilight, !ordered || completed || active
        ? '#fff'
        : theme.colors.tertiary.semilight, bgColor, size, size);
};
var StepIconBg = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t", ";\n"], ["\n\t",
    ";\n"])), function (props) {
    return getIconBg(props.theme, props.ordered, props.status, props.active);
});
var StepIcon = function (_a) {
    var ordered = _a.ordered, status = _a.status, active = _a.active, index = _a.index;
    if (status === 'none') {
        return null;
    }
    return (React.createElement(StepIconBg, { mr: 2, alignItems: "center", justifyContent: "center", ordered: ordered, status: status, active: active }, !ordered || (status === 'completed' && !active) ? (React.createElement(FontAwesomeIcon, { icon: faCheck })) : (React.createElement(Txt, null, index + 1))));
};
var StepBase = function (_a) {
    var ordered = _a.ordered, active = _a.active, index = _a.index, status = _a.status, children = _a.children, onClick = _a.onClick;
    if (typeof children !== 'string') {
        throw new Error('The child of a Step has to be a string.');
    }
    return (React.createElement(Flex, { flexDirection: "row", justifyContent: "center", alignItems: "center" },
        React.createElement(StepIcon, { ordered: Boolean(ordered), status: status, active: Boolean(active), index: index }),
        onClick ? (React.createElement(Link, { onClick: onClick }, children)) : (React.createElement(Txt, { bold: active, color: active ? undefined : 'tertiary.light' }, children))));
};
export var Step = StepBase;
var FramelessSteps = function (_a) {
    var ordered = _a.ordered, activeStepIndex = _a.activeStepIndex, children = _a.children, otherProps = __rest(_a, ["ordered", "activeStepIndex", "children"]);
    return (React.createElement(Flex, __assign({ mx: "auto", flexDirection: "row", alignItems: "center", flexWrap: "wrap" }, otherProps), React.Children.map(children, function (step, index) {
        if (step.type !== Step) {
            throw new Error('You can only use Step components as children of Steps.');
        }
        var firstPendingStepIndex = findIndex(children, {
            props: { status: 'pending' },
        });
        var enableNextStep = !ordered ||
            firstPendingStepIndex === -1 ||
            firstPendingStepIndex > index;
        var allPrevStepsComplete = firstPendingStepIndex === -1 || firstPendingStepIndex >= index;
        var onClick = !ordered ||
            index < activeStepIndex ||
            (index !== activeStepIndex && allPrevStepsComplete)
            ? step.props.onClick
            : undefined;
        return (React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
            React.cloneElement(step, {
                ordered: ordered,
                index: index,
                onClick: onClick,
                active: activeStepIndex === index,
            }),
            index < children.length - 1 && (React.createElement(Flex, { justifyContent: "center", alignItems: "center", mx: 3 },
                React.createElement(Arrow, { disabled: !enableNextStep })))));
    })));
};
var Steps = React.forwardRef(function (_a, ref) {
    var theme = _a.theme, className = _a.className, children = _a.children, ordered = _a.ordered, bordered = _a.bordered, activeStepIndex = _a.activeStepIndex, titleText = _a.titleText, titleIcon = _a.titleIcon, onClose = _a.onClose;
    if (ordered) {
        if (typeof activeStepIndex !== 'number') {
            throw new Error('You must specify the activeStepIndex for ordered Steps');
        }
        else {
            var stepCount = React.Children.count(children);
            if (activeStepIndex < 0 || activeStepIndex >= stepCount) {
                throw new Error('activeStepIndex is out of range');
            }
        }
    }
    return (React.createElement(DismissableContainer, { p: 3, className: className, flexDirection: "row", justifyContent: "space-between", flexWrap: "wrap", alignItems: "center", onDismiss: onClose, baselineHeight: 34, bordered: bordered, ref: ref },
        (titleText || titleIcon) && (React.createElement(Flex, { minHeight: theme.fontSizes[5], justifyContent: "center", alignItems: "center", ml: 2, mr: 4 },
            titleIcon && (React.createElement(Txt, { fontSize: 2, mr: 2, color: "tertiary.semilight" }, titleIcon)),
            titleText && (React.createElement(Heading.h6, { color: "tertiary.main" }, titleText)))),
        React.createElement(FramelessSteps, { ordered: Boolean(ordered), activeStepIndex: activeStepIndex }, children)));
});
Steps.defaultProps = {
    bordered: true,
    ordered: false,
};
export default asRendition(Steps);
var templateObject_1, templateObject_2;
